@@ -1,6 +1,6 @@
 """Models for CloudWanderer data."""
 from enum import Enum, auto, unique
-from typing import Any, Dict, List, NamedTuple, Optional
+from typing import List, NamedTuple
 
 from .urn import PartialUrn
 
@@ -48,15 +48,12 @@ class ServiceResourceType(NamedTuple):
     """A resource type including a service that it is member of.
 
     Attributes:
-        service_name: The name of the service
-        resource_type: The type of resource
-        filter:
-            A dictionary specifying how to filter resources of this type (passed to the cloud interface as a filter arg)
+        service: The name of the service
+        resource_type: The type of resource (snake_case)
     """
 
-    service_name: str
-    name: str
-    filter: Optional[Dict[str, Any]] = None
+    service: str
+    resource_type: str
 
 
 class Relationship(NamedTuple):
